@@ -1,5 +1,6 @@
 from typing import Callable, List, Optional, Generator
 from simpleworkspace.utility.time import StopWatch
+from simpleworkspace.types.time import TimeSpan
 from enum import Enum
 
 try:
@@ -23,9 +24,9 @@ except ImportError:
 
 class _FluentSqlBuilderExecuteResults:
     '''Represents the result of an executed SQL query using FluentSqlBuilder'''
-    def __init__(self, cursor: 'Sqlite3Cursor|MsSqlCursor|MySQLCursor', execution_time_ms):
+    def __init__(self, cursor: 'Sqlite3Cursor|MsSqlCursor|MySQLCursor', elapsed:TimeSpan):
         self._cursor = cursor
-        self.execution_time_ms = execution_time_ms
+        self.elapsed = elapsed
         self._FetchMode_Dictionary = True
         self._scope_transaction_cursor = None
     
@@ -697,7 +698,7 @@ class FluentSqlBuilder:
                 self._connection.commit() #persist changes to database when needed, for free hand queries the caller must do it afterwards
 
         sw.Stop()
-        executionResults = _FluentSqlBuilderExecuteResults(cursor, sw.GetElapsedMilliseconds())
+        executionResults = _FluentSqlBuilderExecuteResults(cursor, sw.Elapsed)
         if(self._scope_transaction_cursor is not None):
             executionResults._scope_transaction_cursor = self._scope_transaction_cursor
         return executionResults
