@@ -1,4 +1,5 @@
 from simpleworkspace import assets
+from simpleworkspace.types.time import TimeSpan as _TimeSpan
 
 def File(audio_file_path):
     """Plays a blocking sound file"""
@@ -11,12 +12,12 @@ def Notification_Completed():
 def Notification_Error():
     File(assets.Audio_Notification_Error)
 
-def Alarm_Sirens(seconds=None):
+def Alarm_Sirens(duration:_TimeSpan=None):
     from simpleworkspace.utility.time import StopWatch
 
     stopwatch = StopWatch()
     stopwatch.Start()
     while True:
         File(assets.Audio_Alarms_Siren)
-        if(seconds is not None) and (stopwatch.GetElapsedSeconds() > seconds):
+        if(duration is not None) and (stopwatch.Elapsed > duration):
             break
