@@ -6,7 +6,6 @@ if(__TYPE_CHECKING__):
     from .types import loader as _types
     from .utility import loader as _utility
     from .db import loader as _db
-    from .collections import loader as _collections
     from .gui import loader as _gui
     from . import logproviders as _logproviders
     from . import settingsproviders as _settingsproviders
@@ -16,7 +15,6 @@ io: '_io' = __LazyImporter__(__package__, '.io.loader')
 types: '_types' = __LazyImporter__(__package__, '.types.loader')
 utility: '_utility' = __LazyImporter__(__package__, '.utility.loader')
 db: '_db' = __LazyImporter__(__package__, '.db.loader')
-collections: '_collections' = __LazyImporter__(__package__, '.collections.loader')
 gui: '_gui' = __LazyImporter__(__package__, '.gui.loader')
 logproviders: '_logproviders' = __LazyImporter__(__package__, '.logproviders')
 settingsproviders: '_settingsproviders' = __LazyImporter__(__package__, '.settingsproviders')
