@@ -1,5 +1,5 @@
 from enum import Enum as _Enum
-from .iunit import IUnit as _IUnit
+from ._iunit import IUnit as _IUnit
 
 class WeightEnum(_Enum):
     '''relative to grams'''
